==> qmmp-0.12.4.tar.bz2: qmmp-0.12.4/src/app/translations/qmmp_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Non ripulire la scaletta</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Inizia il brano scelto</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Sospendi il brano in riproduzione</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Sospendi il brano se in riproduzione; lo riprende se in pausa</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Arresta il brano in esecuzione</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Mostra il menu «Vai al file»</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Chiudi l&apos;applicazione</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Imposta il volume di riproduzione (esempio: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Print volume level</source>
        <translation>Stampa il livello del volume</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Mute/Restore volume</source>
        <translation>Silenzia/ripristina volume</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Print mute status</source>
        <translation>Stampa lo stato del silenzio</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Skip forward in playlist</source>
        <translation>Scorri in avanti nella scaletta</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Skip backwards in playlist</source>
        <translation>Scorri indietro nella scaletta</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Show/hide application</source>
        <translation>Mostra/nascondi il programma</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Show main window</source>
        <translation>Mostra la finestra principale</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="86"/>
        <source>Display Add File dialog</source>
        <translation>Mostra il menu «Aggiungi file»</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="87"/>
        <source>Display Add Directory dialog</source>
        <translation>Mostra il menu «Aggiungi cartella»</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="113"/>
        <source>Unknown command</source>
        <translation>Comando sconosciuto</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="407"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Uso: qmmp [opzioni] [file]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="408"/>
        <source>Options:</source>
        <translation>Opzioni: </translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="414"/>
        <source>Start qmmp with the specified user interface</source>
        <translation>Avvia qmmp con l&apos;interfaccia utente specificata</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="415"/>
        <source>List all available user interfaces</source>
        <translation>Elenca tutte le interfacce utente disponibili</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="416"/>
        <source>Don&apos;t start the application</source>
        <translation>Non avviare l&apos;applicazione</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="417"/>
        <source>Display this text and exit</source>
        <translation>Mostra questo testo ed esci</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="418"/>
        <source>Print version number and exit</source>
        <translation>Stampa il numero di versione ed esci</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="420"/>
        <source>Home page: %1</source>
        <translation>Pagina principale: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="421"/>
        <source>Development page: %1</source>
        <translation>Pagina di sviluppo: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="422"/>
        <source>Bug tracker: %1</source>
        <translation>Segnalazioni di bug: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="135"/>
        <location filename="../qmmpstarter.cpp" line="427"/>
        <source>Command Line Help</source>
        <translation>Aiuto a riga di comando</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="440"/>
        <source>QMMP version: %1</source>
        <translation>QMMP versione: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="441"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Compilato con Qt versione: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="442"/>
        <source>Using Qt version: %1</source>
        <translation>Utilizza Qt versione: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="445"/>
        <source>Qmmp Version</source>
        <translation>Versione di Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="462"/>
        <source>User Interfaces</source>
        <translation>Interfacce utente</translation>
    </message>
</context>
</TS>

==> qmmp_1.0.5.orig.tar.bz2: qmmp-1.0.5/src/app/translations/qmmp_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Skip forward in playlist</source>
        <translation>Scorri in avanti lista dei brani</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Skip backwards in playlist</source>
        <translation>Scorri indietro la lista dei brani</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Inizia il brano scelto</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation type="unfinished">Non ripulire la lista esecuzione</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Sospendi il brano in esecuzione</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Sospendi il brano se in esecuzione; lo riprende se in pausa</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Arresta il brano in esecuzione</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Mostra il menu «Vai al brano»</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Mute/Restore volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Show/hide application</source>
        <translation>Mostra/nascondi Qmmp</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Show main window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Display Add File dialog</source>
        <translation>Mostra il menu «Aggiungi brani»</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Display Add Directory dialog</source>
        <translation>Mostra il menu «Aggiungi cartella»</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="330"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Uso: qmmp [options] [fichiers]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="331"/>
        <source>Options:</source>
        <translation>Opzioni: </translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="337"/>
        <source>Print version number and exit</source>
        <translation>Stampa il numero di versione ed esci</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="338"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>Per idee, modifiche, segnalazione di errori scrivire a: forkotov02@hotmail.ru</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="341"/>
        <source>Command Line Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="354"/>
        <source>QMMP version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="355"/>
        <source>Compiled with Qt version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="356"/>
        <source>Using Qt version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="359"/>
        <source>Qmmp Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="336"/>
        <source>Display this text and exit</source>
        <translation>Mostra questo testo ed esci</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="94"/>
        <source>Unknown command</source>
        <translation>Comando sconosciuto</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="335"/>
        <source>Don&apos;t start the application</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
